/***************************************************************************
                          autologinview.h  -  description
                             -------------------
    begin                : Mon Feb 10 2003
    copyright            : (C) 2003 by Mike K. Bennett
    email                : mkb137b@hotmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef AUTOLOGINVIEW_H
#define AUTOLOGINVIEW_H

#include <qwidget.h>

/**
 * @brief The login status message widget.
 *
 * This class displays the "Logging in..." status message
 * in the main window, and displays the KMess icon.
 *
 * @author Mike K. Bennett
 * @ingroup Root
 */
class AutologinView : public QWidget
{
  Q_OBJECT

  public:
    // The constructor
  	AutologinView(QWidget *parent=0, const char *name=0);
    // The destructor
  	~AutologinView();
};

#endif
